﻿using System;
using System.Windows.Forms;

using DevExpress.XtraEditors;
using DevExpress.XtraMap;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 빙 맵 키
        /// </summary>
        private string bingKey = "INPUT YOUR BING KEY";

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load += Form_Load;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            MapControl mapControl = new MapControl();

            mapControl.Dock        = DockStyle.Fill;
            mapControl.ZoomLevel   = 4;
            mapControl.CenterPoint = new GeoPoint(43, 15);

            Controls.Add(mapControl);

            BingMapDataProvider bingMapDataProvider = new BingMapDataProvider();

            bingMapDataProvider.BingKey = this.bingKey;

            ImageLayer imageLayer = new ImageLayer();

            imageLayer.DataProvider = bingMapDataProvider;

            mapControl.Layers.Add(imageLayer);

            VectorItemsLayer vectorItemsLayer = new VectorItemsLayer();

            mapControl.Layers.Add(vectorItemsLayer);

            MapItemStorage storage = new MapItemStorage();

            MapItem[] mapItemArray = GetMapItemArray();

            storage.Items.AddRange(mapItemArray);

            vectorItemsLayer.Data = storage;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 맵 항목 배열 구하기 - GetMapItemArray()

        /// <summary>
        /// 맵 항목 배열 구하기
        /// </summary>
        /// <returns>맵 항목 배열</returns>
        private MapItem[] GetMapItemArray()
        {
            return new MapItem[]
            { 
                new MapCallout() { Text = "London", Location = new GeoPoint(51.507222, -0.1275) },
                new MapCallout() { Text = "Rome"  , Location = new GeoPoint(41.9     , 12.5   ) },
                new MapCallout() { Text = "Paris" , Location = new GeoPoint(48.8567  , 2.3508 ) },
                new MapCallout() { Text = "Berlin", Location = new GeoPoint(52.52    , 13.38  ) },
                new MapCallout() { Text = "Madrid", Location = new GeoPoint(40.4     , -3.68  ) }
            };
        }

        #endregion
    }
}